VideoAudioAnswer class

Answer for a video/audio/photo/text capture question.

Constructors

VideoAudioAnswer({required String mode, String? fileUrl, String? text, int? durationSeconds, String? transcriptText})
const

Properties

durationSeconds int?
final
fileUrl String?
final
hashCode int
The hash code for this object.
no setterinherited
mode String
The answer mode: 'video', 'audio', 'photo', or 'text'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final
transcriptText String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited